=========
Changelog
=========

unreleased
==========
-

Version 0.2
===========
- Add Version 05.2 grid definition
- Add high VOD mask and ESA CCI LC classes.
- Allow reducing grid based on ESA CCI LC classes
- Allow reducing grid based on Koeppen-Geiger climate classes


Version 0.1
===========

- First version of package, including grid version 04.2
- Basic documentation
- Public pypi release
